@@ -3,7 +3,7 @@ package copyloopvar
 import (
 	"testing"
 
-	"github.com/golangci/golangci-lint/test/testshared/integration"
+	"github.com/golangci/golangci-lint/v2/test/testshared/integration"
 )
 
 func TestFromTestdata(t *testing.T) {
