@@ -1,4 +1,3 @@
-//golangcitest:args -Egci
 //golangcitest:config_path testdata/gci.yml
 package testdata
 
@@ -14,7 +13,7 @@ import "C"
 
 import (
 	"golang.org/x/tools/go/analysis" // want "File is not properly formatted"
-	"github.com/golangci/golangci-lint/pkg/config"
+	"github.com/golangci/golangci-lint/v2/pkg/config"
 	"fmt"
 	"errors"
 	gcicfg "github.com/daixiang0/gci/pkg/config"
