@@ -24,14 +24,6 @@ func GovetShadow(f io.Reader, buf []byte) (err error) {
 	return
 }
 
-func GovetNolintVet() error {
-	return &os.PathError{"first", "path", os.ErrNotExist} //nolint:vet
-}
-
-func GovetNolintVetShadow() error {
-	return &os.PathError{"first", "path", os.ErrNotExist} //nolint:vetshadow
-}
-
 func GovetPrintf() {
 	x := "dummy"
 	fmt.Printf("%d", x) // want "printf: fmt.Printf format %d has arg x of wrong type string"
