@@ -2,7 +2,6 @@ package nakedret
 
 import (
 	"github.com/alexkohler/nakedret/v2"
-	"golang.org/x/tools/go/analysis"
 
 	"github.com/golangci/golangci-lint/v2/pkg/config"
 	"github.com/golangci/golangci-lint/v2/pkg/goanalysis"
@@ -16,12 +15,7 @@ func New(settings *config.NakedretSettings) *goanalysis.Linter {
 		cfg.MaxLength = settings.MaxFuncLines
 	}
 
-	a := nakedret.NakedReturnAnalyzer(cfg)
-
-	return goanalysis.NewLinter(
-		a.Name,
-		a.Doc,
-		[]*analysis.Analyzer{a},
-		nil,
-	).WithLoadMode(goanalysis.LoadModeSyntax)
+	return goanalysis.
+		NewLinterFromAnalyzer(nakedret.NakedReturnAnalyzer(cfg)).
+		WithLoadMode(goanalysis.LoadModeSyntax)
 }
