@@ -2,7 +2,6 @@ package whitespace
 
 import (
 	"github.com/ultraware/whitespace"
-	"golang.org/x/tools/go/analysis"
 
 	"github.com/golangci/golangci-lint/v2/pkg/config"
 	"github.com/golangci/golangci-lint/v2/pkg/goanalysis"
@@ -17,12 +16,7 @@ func New(settings *config.WhitespaceSettings) *goanalysis.Linter {
 		}
 	}
 
-	a := whitespace.NewAnalyzer(&wsSettings)
-
-	return goanalysis.NewLinter(
-		a.Name,
-		a.Doc,
-		[]*analysis.Analyzer{a},
-		nil,
-	).WithLoadMode(goanalysis.LoadModeSyntax)
+	return goanalysis.
+		NewLinterFromAnalyzer(whitespace.NewAnalyzer(&wsSettings)).
+		WithLoadMode(goanalysis.LoadModeSyntax)
 }
