@@ -12,7 +12,7 @@ import (
 )
 
 func TestJUnitXML_Print(t *testing.T) {
-	issues := []result.Issue{
+	issues := []*result.Issue{
 		{
 			FromLinter: "linter-a",
 			Severity:   "warning",
